'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.makeSafeProxy = makeSafeProxy;
exports.directCompose = directCompose;
exports.reverseCompose = reverseCompose;
function makeSafeProxy(obj, onError) {
  if (typeof Proxy !== 'function') {
    return obj;
  }
  var safeGet = function safeGet(target, property) {
    if (property in target) {
      return target[property];
    } else {
      return onError(target, property);
    }
  };
  return new Proxy(obj, { get: safeGet });
}

function directCompose(secondReducer, firstReducer) {
  if (!firstReducer) {
    return secondReducer;
  }
  if (!secondReducer) {
    return firstReducer;
  }
  return function (state, action) {
    return secondReducer(firstReducer(state, action), action);
  };
}

function reverseCompose(firstReducer, secondReducer) {
  if (!firstReducer) {
    return secondReducer;
  }
  if (!secondReducer) {
    return firstReducer;
  }
  return function (state, action) {
    return secondReducer(firstReducer(state, action), action);
  };
}